@@ -24,6 +24,8 @@ SHIM_MAP = {
     "cpp": "cpp",
     "ld": "ld",
     "as": "as",
+    "ar": "ar",
+    "strip": "strip",
 
     # GNU shims.
     "gcc": "cc",
@@ -57,7 +59,7 @@ def _export_guess_wrapped():
         _export(f"BLIGHT_WRAPPED_{variable}", tool_path)
 
 
-def _swizzle_path():
+def _swizzle_path(stubs):
     blight_dir = Path(tempfile.mkdtemp(suffix=blight.util.SWIZZLE_SENTINEL))
 
     for shim, tool in SHIM_MAP.items():
@@ -68,6 +70,14 @@ def _swizzle_path():
 
         shim_path.chmod(shim_path.stat().st_mode | stat.S_IEXEC)
 
+    for stub in stubs:
+        stub_path = blight_dir / stub
+        with open(stub_path, "w+") as io:
+            print("#!/bin/sh", file=io)
+            print("true", file=io)
+
+        stub_path.chmod(stub_path.stat().st_mode | stat.S_IEXEC)
+
     _export("PATH", f"{blight_dir}:{unswizzled_path()}")
 
 
@@ -76,13 +86,14 @@ def _swizzle_path():
     "--guess-wrapped", help="Attempt to guess the appropriate programs to wrap", is_flag=True
 )
 @click.option("--swizzle-path", help="Wrap via PATH swizzling", is_flag=True)
+@click.option("--stub", help="Stub a command out while swizzling", multiple=True)
 @click.option("--unset", help="Unset the tool variables instead of setting them", is_flag=True)
-def env(unset, guess_wrapped, swizzle_path):
+def env(unset, guess_wrapped, swizzle_path, stub):
     if guess_wrapped:
         _export_guess_wrapped()
 
     if swizzle_path:
-        _swizzle_path()
+        _swizzle_path(stub)
 
     for variable, tool in blight.tool.TOOL_ENV_MAP.items():
         if unset:
