@@ -12,7 +12,7 @@ from typing import Any, Dict, List, Tuple
 
 from blight import util
 from blight.enums import CodeModel, CompilerStage, Lang, OptLevel, Std
-from blight.exceptions import BlightError, BuildError
+from blight.exceptions import BlightError, BuildError, SkipRun
 from blight.protocols import CanonicalizedArgsProtocol, IndexedUndefinesProtocol, LangProtocol
 
 logger = logging.getLogger(__name__)
@@ -24,9 +24,18 @@ BLIGHT_TOOL_MAP = {
     "blight-ld": "LD",
     "blight-as": "AS",
     "blight-ar": "AR",
+    "blight-strip": "AR",
 }
 
-TOOL_ENV_MAP = {"CC": "cc", "CXX": "c++", "CPP": "cpp", "LD": "ld", "AS": "as", "AR": "ar"}
+TOOL_ENV_MAP = {
+    "CC": "cc",
+    "CXX": "c++",
+    "CPP": "cpp",
+    "LD": "ld",
+    "AS": "as",
+    "AR": "ar",
+    "STRIP": "strip",
+}
 
 TOOL_ENV_WRAPPER_MAP = {
     "CC": "BLIGHT_WRAPPED_CC",
@@ -35,6 +44,7 @@ TOOL_ENV_WRAPPER_MAP = {
     "LD": "BLIGHT_WRAPPED_LD",
     "AS": "BLIGHT_WRAPPED_AS",
     "AR": "BLIGHT_WRAPPED_AR",
+    "STRIP": "BLIGHT_WRAPPED_STRIP",
 }
 
 RESPONSE_FILE_RECURSION_LIMIT = 64
@@ -91,6 +101,7 @@ class Tool:
         self._env = self._fixup_env()
         self._cwd = Path(os.getcwd()).resolve()
         self._actions = util.load_actions()
+        self._skip_run = False
 
     def _fixup_env(self):
         """
@@ -103,11 +114,14 @@ class Tool:
 
     def _before_run(self):
         for action in self._actions:
-            action._before_run(self)
+            try:
+                action._before_run(self)
+            except SkipRun:
+                self._skip_run = True
 
     def _after_run(self):
         for action in self._actions:
-            action._after_run(self)
+            action._after_run(self, run_skipped=self._skip_run)
 
     def run(self):
         """
@@ -115,9 +129,12 @@ class Tool:
         """
         self._before_run()
 
-        status = subprocess.run([self.wrapped_tool(), *self.args])
-        if status.returncode != 0:
-            raise BuildError(f"{self.wrapped_tool()} exited with status code {status.returncode}")
+        if not self._skip_run:
+            status = subprocess.run([self.wrapped_tool(), *self.args])
+            if status.returncode != 0:
+                raise BuildError(
+                    f"{self.wrapped_tool()} exited with status code {status.returncode}"
+                )
 
         self._after_run()
 
@@ -362,6 +379,7 @@ class StdMixin(LangMixin):
             "-std=c++1z": Std.Cxx17,
             # C++20 (presumptive) flags.
             "-std=c++2a": Std.Cxx2a,
+            "-std=c++20": Std.Cxx2a,
             # GNU++03 flags.
             "-std=gnu++98": Std.Gnuxx03,
             "-std=gnu++03": Std.Gnuxx03,
@@ -376,6 +394,7 @@ class StdMixin(LangMixin):
             "-std=gnu++1z": Std.Gnuxx17,
             # GNU++20 (presumptive) flags.
             "-std=gnu++2a": Std.Gnuxx2a,
+            "-std=gnu++20": Std.Gnuxx2a,
         }
 
         std = std_flag_map.get(last_std_flag)
@@ -783,3 +802,12 @@ class AR(Tool):
 
     def __repr__(self) -> str:
         return f"<AR {self.wrapped_tool()}>"
+
+
+class STRIP(ResponseFileMixin, Tool):
+    """
+    Represents the stripping tool.
+    """
+
+    def __repr__(self) -> str:
+        return f"<STRIP {self.wrapped_tool()}>"
